# The correct idiom is
# from mateweather.I_KNOW_THIS_IS_UNSTABLE import mateweather

def location_new_world(use_regions):
    raise ImportError("libmateweather should only be used if you understand that it's subject to change, and is not supported as a fixed API/ABI or as part of the platform")

def location_entry_new(top):
    raise ImportError("libmateweather should only be used if you understand that it's subject to change, and is not supported as a fixed API/ABI or as part of the platform")

def timezone_menu_new(top):
    raise ImportError("libmateweather should only be used if you understand that it's subject to change, and is not supported as a fixed API/ABI or as part of the platform")



from mateweather.I_KNOW_THIS_IS_UNSTABLE import mateweather

for loc in mateweather.location_new_world(False).get_children():
    print loc.get_name()
    for zone in loc.get_timezones():
        if zone.get_name() is not None:
            print "  %s" % zone.get_name()
